..
  This file is generated by setup.py

Read Becker & Hickl SDT files
=============================

Sdtfile is a Python library to read SDT files produced by Becker & Hickl
SPCM software. SDT files contain time correlated single photon counting
instrumentation parameters and measurement data. Currently only the
"Setup & Data", "DLL Data", and "FCS Data" formats are supported.

`Becker & Hickl GmbH <http://www.becker-hickl.de/>`_ is a manufacturer of
equipment for photon counting.

:Author: `Christoph Gohlke <https://www.cgohlke.com>`_
:License: BSD-3-Clause
:Version: 2026.2.8
:DOI: `10.5281/zenodo.10125608 <https://doi.org/10.5281/zenodo.10125608>`_

Quickstart
----------

Install the sdtfile package and all dependencies from the
`Python Package Index <https://pypi.org/project/sdtfile/>`_::

    python -m pip install -U sdtfile

See `Examples`_ for using the programming interface.

Source code and support are available on
`GitHub <https://github.com/cgohlke/sdtfile>`_.

Requirements
------------

This revision was tested with the following requirements and dependencies
(other versions may work):

- `CPython <https://www.python.org>`_ 3.11.9, 3.12.10, 3.13.12, 3.14.3 64-bit
- `NumPy <https://pypi.org/project/numpy>`_ 2.4.2

Revisions
---------

2026.2.8

- Derive SdtFile from BinaryFile (breaking).
- Rename MEASURE_INFO.MeasHISTInfo to HISTInfo to match C struct (breaking).
- Revise shaping of FCS_BLOCK data (breaking).
- Fix code review issues.

2026.1.14

- Improve code quality.

2025.12.12

- Add new SPC modules and MEASURE_INFO_EXT fields.
- Drop support for Python 3.10.

2025.5.10

- Support Python 3.14.

2025.3.25

- Fix shape of data with routing channels.
- Drop support for Python 3.9, support Python 3.13.

2024.12.6

- Fix read MeasureInfo fields as scalars (breaking).
- Update some structure field names with BH reference (breaking).
- Parse some SetupBlock binary structures (#7).
- Include more information in str(SdtFile).
- Add subtype to FileRevision.

2024.11.24

- …

Refer to the CHANGES file for older revisions.

References
----------

1. W Becker. The bh TCSPC Handbook. 9th Edition. Becker & Hickl GmbH 2021.
   pp 879.
2. SPC_data_file_structure.h header file. Part of the Becker & Hickl
   SPCM software installation.

Examples
--------

Read image and metadata from a "SPC Setup & Data File":

.. code-block:: python

    >>> sdt = SdtFile('image.sdt')
    >>> int(sdt.header.revision)
    588
    >>> sdt.info.id[1:-1]
    'SPC Setup & Data File'
    >>> int(sdt.measure_info[0].scan_x)
    128
    >>> len(sdt.data)
    1
    >>> sdt.data[0].shape
    (128, 128, 256)
    >>> sdt.times[0].shape
    (256,)

Read data and metadata from a "SPC Setup & Data File" with multiple data sets:

.. code-block:: python

    >>> sdt = SdtFile('fluorescein.sdt')
    >>> len(sdt.data)
    4
    >>> sdt.data[3].shape
    (1, 1024)
    >>> sdt.times[3].shape
    (1024,)
    >>> int(sdt.setup.bh_bin_hdr['soft_rev'])
    850

Read image data from a "SPC FCS Data File" as numpy array:

.. code-block:: python

    >>> sdt = SdtFile('fcs.sdt')
    >>> sdt.info.id[1:-1]
    'SPC FCS Data File'
    >>> len(sdt.data)
    1
    >>> sdt.data[0].shape
    (512, 512, 256)
    >>> sdt.times[0].shape
    (256,)